@@ -11,14 +11,12 @@ __PACKAGE__->load_namespaces(
 );
 
 our # try to hide from kwalitee
-  $VERSION # try harder
-    = 41; # schema version used for upgrades, keep as integer
+  $VERSION = 41; # schema version used for upgrades, keep as integer
 
 use Path::Class;
-use File::Basename;
+use File::ShareDir 'dist_dir';
 
-my (undef, $libpath, undef) = fileparse( $INC{ 'App/Netdisco/DB.pm' } );
-our $schema_versions_dir = Path::Class::Dir->new($libpath)
+our $schema_versions_dir = Path::Class::Dir->new( dist_dir('App-Netdisco') )
   ->subdir("DB", "schema_versions")->stringify;
 
 __PACKAGE__->load_components(qw/
